export declare const COLOR_TOKEN: Readonly<{
    /**
     * Page 배경색
     */
    bg: {
        light: string;
        dark: "#000000";
    };
    /**
     * Card, Modal, Popover 등의 컴포넌트 배경색
     */
    surface: {
        light: "#FFFFFF";
        dark: "#15181E";
    };
    /**
     * Card, Modal, Popover 등의 컴포넌트 보조 배경색
     */
    "surface-sub": {
        light: "#F8F9FB";
        dark: "#1D2027";
    };
    /**
     * 설명
     */
    "surface-slate": {
        light: "#E2E5E9";
        dark: "rgba(115, 120, 130, 0.15)";
    };
    /**
     * 설명
     */
    "surface-accent": {
        light: "#F3F8FF";
        dark: "rgba(133, 189, 255, 0.15)";
    };
    /**
     * 배지를 포함한 Critical 요소의 배경 색상으로, 오류 및 즉각적인 조치가 필요한 중요한 이벤트에 사용합니다.
     */
    "surface-critical": {
        light: "#FFF2F3";
        dark: "rgba(254, 88, 104, 0.15)";
    };
    /**
     * 경고 요소의 배경 색상으로, 사용자에게 조치가 필요함을 알리고 배지, 배너 및 예외 목록에 적용됩니다.
     */
    "surface-warning": {
        light: "#FFF6E7";
        dark: "rgba(255, 168, 17, 0.15)";
    };
    /**
     * 배지를 포함한 성공 요소의 배경 색상으로, 사용자 행동의 성공 또는 성장을 설명하는 것과 같이 긍정적인 것을 나타냅니다.
     */
    "surface-success": {
        light: "#E5FBF6";
        dark: "rgba(0, 219, 163, 0.15)";
    };
    /**
     * 정보 요소의 배경 색상으로, 즉각적인 조치가 필요하지 않은 중요한 요소를 나타냅니다. 정보 배너 및 배지, 새로운 정보에 주의를 환기시키는 표시기, 로드 또는 진행률 표시줄, 데이터 시각화와 함께 사용됩니다.
     */
    "surface-highlight": {
        light: "#F3F8FF";
        dark: "rgba(133, 189, 255, 0.15)";
    };
    /** Primary textfield 배경색 */
    "field-primary": {
        light: "#E8F0FF";
        dark: "rgba(26, 109, 255, 0.15)";
    };
    /** Secondary textfield 배경색 */
    "field-secondary": {
        light: "#F8F9FB";
        dark: "#24282F";
    };
    /**
     * Textfield의 Typing 상태
     * 선택된 체크박스와 라디오 버튼의 채우기 색상
     */
    focus: {
        light: "#1A6DFF";
        dark: "#4788FF";
    };
    /**
     * Primary button 배경색
     */
    "action-primary": {
        light: "#1A6DFF";
        dark: "#4788FF";
    };
    /**
     * Primary button hover color
     */
    "action-primary-hover": {
        light: "#70A2FF";
        dark: "#70A2FF";
    };
    /**
     * Primary button pressed color
     */
    "action-primary-pressed": {
        light: "#99BDFF";
        dark: "#99BDFF";
    };
    /**
     * Primary button disabled color
     */
    "action-primary-disabled": {
        light: "rgba(115, 120, 130, 0.15)";
        dark: "rgba(115, 120, 130, 0.15)";
    };
    /**
     * Secondary button 배경색
     */
    "action-secondary": {
        light: "#FFFFFF";
        dark: "#15181E";
    };
    /**
     * secondary button hover color
     */
    "action-secondary-hover": {
        light: "#F8F9FB";
        dark: "rgba(115, 120, 130, 0.15)";
    };
    /**
     * secondary button pressed color
     */
    "action-secondary-pressed": {
        light: "#E2E5E9";
        dark: "#24282F";
    };
    /**
     * secondary button disabled color
     */
    "action-secondary-disabled": {
        light: "rgba(115, 120, 130, 0.15)";
        dark: "rgba(115, 120, 130, 0.15)";
    };
    /**
     * Floating action button(FAB) 배경색
     */
    "action-tertiary": {
        light: "#15181E";
        dark: "#1D2027";
    };
    /**
     * Floating action button(FAB) hover color
     */
    "action-tertiary-hover": {
        light: "#24282F";
        dark: "#4B515B";
    };
    /**
     * Critical button 배경색
     */
    "action-critical": {
        light: "#FE5868";
        dark: "#FE5868";
    };
    /**
     * Critical button hover color
     */
    "action-critical-hover": {
        light: "#FEA3AC";
        dark: "#FE7683";
    };
    /**
     * Critical button pressed color
     */
    "action-critical-pressed": {
        light: "#FECDD3";
        dark: "#FEA3AC";
    };
    /**
     * Critical button disabled color
     */
    "action-critical-disabled": {
        light: "rgba(115, 120, 130, 0.15)";
        dark: "rgba(115, 120, 130, 0.15)";
    };
    /**
     * Floating action button(FAB) 배경색
     */
    "action-toggle": {
        light: "rgba(115, 120, 130, 0.15)";
        dark: "rgba(115, 120, 130, 0.15)";
    };
    /**
     * 특정 요소를 투명도가 있는 어두운 색상으로 가려야 할 때 사용 (Modal, Side sheet)
     */
    backdrop: {
        light: string;
        dark: string;
    };
    /**
     * Default border color
     */
    border: {
        light: "#DBDEE3";
        dark: "rgba(115, 120, 130, 0.15)";
    };
    /**
     * Default border hover color (액션 기능이 있을 경우)
     */
    "border-hover": {
        light: "#70A2FF";
        dark: "#0047CC";
    };
    /**
     * Sub border color
     */
    "border-sub": {
        light: "#717680";
        dark: "#4B515B";
    };
    /**
     * Sub border color
     */
    "border-minimal": {
        light: "#BCC0C6";
        dark: "#4B515B";
    };
    /**
     * Error, Critical border color
     */
    "border-critical": {
        light: "#DD3344";
        dark: "#FE7683";
    };
    /**
     * Error, Critical border hover color (액션 기능이 있을 경우)
     */
    "border-critical-hover": {
        light: "#FEA3AC";
        dark: "#FECDD3";
    };
    /**
     * Warning border color
     */
    "border-warning": {
        light: "#E5970F";
        dark: "#FFC258";
    };
    /**
     * Success border color
     */
    "border-success": {
        light: "#00BA8B";
        dark: "#4CE6BF";
    };
    /**
     * Informative border color
     */
    "border-highlight": {
        light: "#4C6C91";
        dark: "#6A97CC";
    };
    /**
     * 요소 사이 구분 선
     */
    divide: {
        light: "#E2E5E9";
        dark: "#1D2027";
    };
    /**
     * 요소 사이의 보조 구분 선
     */
    "divide-sub": {
        light: "#717680";
        dark: "#1D2027";
    };
    /**
     * 요소 사이의 보조 구분 선
     */
    "divide-minimal": {
        light: "#F8F9FB";
        dark: "#1D2027";
    };
    /**
     * Default text, Primary label color
     */
    text: {
        light: "#15181E";
        dark: "#FFFFFF";
    };
    /**
     * Sub text, Secondary label, Placeholder color
     */
    "text-sub": {
        light: "#717680";
        dark: "#717680";
    };
    /**
     * Disabled text, Placeholder disabled text color
     */
    "text-disabled": {
        light: "#BCC0C6";
        dark: "#4B515B";
    };
    /**
     * Error, Critical state text color
     */
    "text-critical": {
        light: "#DD3344";
        dark: "#FE7683";
    };
    /**
     * Error, Critical text hover color (액션 기능이 있을 경우)
     */
    "text-critical-hover": {
        light: "#FE7683";
        dark: "#FECDD3";
    };
    /**
     * Warning state text color
     */
    "text-warning": {
        light: "#D68C0C";
        dark: "#FFC258";
    };
    /**
     * Warning text hover color (액션 기능이 있을 경우)
     */
    "text-warning-hover": {
        light: "#FFC258";
        dark: "#FFE0AC";
    };
    /**
     * Success text color
     */
    "text-success": {
        light: "#009972";
        dark: "#4CE6BF";
    };
    /**
     * Link text, Primary text button color
     */
    "text-primary": {
        light: "#1A6DFF";
        dark: "#4788FF";
    };
    /**
     * Link text, Primary text button hover color
     */
    "text-primary-hover": {
        light: "#70A2FF";
        dark: "#70A2FF";
    };
    /**
     * Secondary text button color
     */
    "text-secondary": {
        light: "#717680";
        dark: "#BCC0C6";
    };
    /**
     * Secondary text button hover color
     */
    "text-secondary-hover": {
        light: "#9FA3AB";
        dark: "#DBDEE3";
    };
    /**
     * Primary, Critical, Text on button text color
     */
    "text-on": {
        light: "#FFFFFF";
        dark: "#FFFFFF";
    };
    /**
     * Default icon color
     */
    icon: {
        light: "#15181E";
        dark: "#FFFFFF";
    };
    /**
     * Sub icon color
     */
    "icon-sub": {
        light: "#717680";
        dark: "#717680";
    };
    /**
     * Disabled icon color
     */
    "icon-disabled": {
        light: "#BCC0C6";
        dark: "#4B515B";
    };
    /**
     * Error, Critical state icon color
     */
    "icon-critical": {
        light: "#DD3344";
        dark: "#FE7683";
    };
    /**
     * Error, Critical icon hover color (액션 기능이 있을 경우)
     */
    "icon-critical-hover": {
        light: "#FE7683";
        dark: "#FECDD3";
    };
    /**
     * Warning state icon color
     */
    "icon-warning": {
        light: "#D68C0C";
        dark: "#FFC258";
    };
    /**
     * Warning icon hover color (액션 기능이 있을 경우)
     */
    "icon-warning-hover": {
        light: "#FFC258";
        dark: "#FFE0AC";
    };
    /**
     * Success icon color
     */
    "icon-success": {
        light: "#009972";
        dark: "#4CE6BF";
    };
    /**
     * Primary button icon color
     */
    "icon-primary": {
        light: "#1A6DFF";
        dark: "#4788FF";
    };
    /**
     * Primary button icon hover color
     */
    "icon-primary-hover": {
        light: "#70A2FF";
        dark: "#70A2FF";
    };
    /**
     * Secondary button icon color
     */
    "icon-secondary": {
        light: "#717680";
        dark: "#BCC0C6";
    };
    /**
     * Secondary button icon hover color
     */
    "icon-secondary-hover": {
        light: "#9FA3AB";
        dark: "#DBDEE3";
    };
    /**
     * Primary, Critical, Text on button text color
     */
    "icon-on": {
        light: "#FFFFFF";
        dark: "#FFFFFF";
    };
}>;
