import { PALETTE_TOKEN } from './palette.token.mjs';

var COLOR_TOKEN = Object.freeze({
  /**
   * Page 배경색
   */
  bg: {
    light: "#EDF0F4",
    // 레거시에서 사용하는 색상이라 파레트에 없다고 합니다.
    dark: PALETTE_TOKEN["slate-black"]
  },
  /**
   * Card, Modal, Popover 등의 컴포넌트 배경색
   */
  surface: {
    light: PALETTE_TOKEN["slate-white"],
    dark: PALETTE_TOKEN["slate-900"]
  },
  /**
   * Card, Modal, Popover 등의 컴포넌트 보조 배경색
   */
  "surface-sub": {
    light: PALETTE_TOKEN["slate-50"],
    dark: PALETTE_TOKEN["slate-800"]
  },
  /**
   * 설명
   */
  "surface-slate": {
    light: PALETTE_TOKEN["slate-100"],
    dark: PALETTE_TOKEN["slate-tint-15"]
  },
  /**
   * 설명
   */
  "surface-accent": {
    light: PALETTE_TOKEN["skyblue-50"],
    dark: PALETTE_TOKEN["skyblue-tint-15"]
  },
  /**
   * 배지를 포함한 Critical 요소의 배경 색상으로, 오류 및 즉각적인 조치가 필요한 중요한 이벤트에 사용합니다.
   */
  "surface-critical": {
    light: PALETTE_TOKEN["raspberry-50"],
    dark: PALETTE_TOKEN["raspberry-tint-15"]
  },
  /**
   * 경고 요소의 배경 색상으로, 사용자에게 조치가 필요함을 알리고 배지, 배너 및 예외 목록에 적용됩니다.
   */
  "surface-warning": {
    light: PALETTE_TOKEN["mango-50"],
    dark: PALETTE_TOKEN["mango-tint-15"]
  },
  /**
   * 배지를 포함한 성공 요소의 배경 색상으로, 사용자 행동의 성공 또는 성장을 설명하는 것과 같이 긍정적인 것을 나타냅니다.
   */
  "surface-success": {
    light: PALETTE_TOKEN["mint-50"],
    dark: PALETTE_TOKEN["mint-tint-15"]
  },
  /**
   * 정보 요소의 배경 색상으로, 즉각적인 조치가 필요하지 않은 중요한 요소를 나타냅니다. 정보 배너 및 배지, 새로운 정보에 주의를 환기시키는 표시기, 로드 또는 진행률 표시줄, 데이터 시각화와 함께 사용됩니다.
   */
  "surface-highlight": {
    light: PALETTE_TOKEN["skyblue-50"],
    dark: PALETTE_TOKEN["skyblue-tint-15"]
  },
  /** Primary textfield 배경색 */
  "field-primary": {
    light: PALETTE_TOKEN["im-blue-50"],
    dark: PALETTE_TOKEN["im-blue-tint-15"]
  },
  /** Secondary textfield 배경색 */
  "field-secondary": {
    light: PALETTE_TOKEN["slate-50"],
    dark: PALETTE_TOKEN["slate-700"]
  },
  /**
   * Textfield의 Typing 상태
   * 선택된 체크박스와 라디오 버튼의 채우기 색상
   */
  focus: {
    light: PALETTE_TOKEN["im-blue-500"],
    dark: PALETTE_TOKEN["im-blue-400"]
  },
  /**
   * Primary button 배경색
   */
  "action-primary": {
    light: PALETTE_TOKEN["im-blue-500"],
    dark: PALETTE_TOKEN["im-blue-400"]
  },
  /**
   * Primary button hover color
   */
  "action-primary-hover": {
    light: PALETTE_TOKEN["im-blue-300"],
    dark: PALETTE_TOKEN["im-blue-300"]
  },
  /**
   * Primary button pressed color
   */
  "action-primary-pressed": {
    light: PALETTE_TOKEN["im-blue-200"],
    dark: PALETTE_TOKEN["im-blue-200"]
  },
  /**
   * Primary button disabled color
   */
  "action-primary-disabled": {
    light: PALETTE_TOKEN["slate-tint-15"],
    dark: PALETTE_TOKEN["slate-tint-15"]
  },
  /**
   * Secondary button 배경색
   */
  "action-secondary": {
    light: PALETTE_TOKEN["slate-white"],
    dark: PALETTE_TOKEN["slate-900"]
  },
  /**
   * secondary button hover color
   */
  "action-secondary-hover": {
    light: PALETTE_TOKEN["slate-50"],
    dark: PALETTE_TOKEN["slate-tint-15"]
  },
  /**
   * secondary button pressed color
   */
  "action-secondary-pressed": {
    light: PALETTE_TOKEN["slate-100"],
    dark: PALETTE_TOKEN["slate-700"]
  },
  /**
   * secondary button disabled color
   */
  "action-secondary-disabled": {
    light: PALETTE_TOKEN["slate-tint-15"],
    dark: PALETTE_TOKEN["slate-tint-15"]
  },
  /**
   * Floating action button(FAB) 배경색
   */
  "action-tertiary": {
    light: PALETTE_TOKEN["slate-900"],
    dark: PALETTE_TOKEN["slate-800"]
  },
  /**
   * Floating action button(FAB) hover color
   */
  "action-tertiary-hover": {
    light: PALETTE_TOKEN["slate-700"],
    dark: PALETTE_TOKEN["slate-600"]
  },
  /**
   * Critical button 배경색
   */
  "action-critical": {
    light: PALETTE_TOKEN["raspberry-500"],
    dark: PALETTE_TOKEN["raspberry-500"]
  },
  /**
   * Critical button hover color
   */
  "action-critical-hover": {
    light: PALETTE_TOKEN["raspberry-300"],
    dark: PALETTE_TOKEN["raspberry-400"]
  },
  /**
   * Critical button pressed color
   */
  "action-critical-pressed": {
    light: PALETTE_TOKEN["raspberry-200"],
    dark: PALETTE_TOKEN["raspberry-300"]
  },
  /**
   * Critical button disabled color
   */
  "action-critical-disabled": {
    light: PALETTE_TOKEN["slate-tint-15"],
    dark: PALETTE_TOKEN["slate-tint-15"]
  },
  /**
   * Floating action button(FAB) 배경색
   */
  "action-toggle": {
    light: PALETTE_TOKEN["slate-tint-15"],
    dark: PALETTE_TOKEN["slate-tint-15"]
  },
  /**
   * 특정 요소를 투명도가 있는 어두운 색상으로 가려야 할 때 사용 (Modal, Side sheet)
   */
  backdrop: {
    light: "rgba(11, 12, 14, 0.75)",
    dark: "rgba(0, 0, 0, 0.75)"
  },
  /**
   * Default border color
   */
  border: {
    light: PALETTE_TOKEN["slate-200"],
    dark: PALETTE_TOKEN["slate-tint-15"]
  },
  /**
   * Default border hover color (액션 기능이 있을 경우)
   */
  "border-hover": {
    light: PALETTE_TOKEN["im-blue-300"],
    dark: PALETTE_TOKEN["im-blue-700"]
  },
  /**
   * Sub border color
   */
  "border-sub": {
    light: PALETTE_TOKEN["slate-500"],
    dark: PALETTE_TOKEN["slate-600"]
  },
  /**
   * Sub border color
   */
  "border-minimal": {
    light: PALETTE_TOKEN["slate-300"],
    dark: PALETTE_TOKEN["slate-600"]
  },
  /**
   * Error, Critical border color
   */
  "border-critical": {
    light: PALETTE_TOKEN["raspberry-600"],
    dark: PALETTE_TOKEN["raspberry-400"]
  },
  /**
   * Error, Critical border hover color (액션 기능이 있을 경우)
   */
  "border-critical-hover": {
    light: PALETTE_TOKEN["raspberry-300"],
    dark: PALETTE_TOKEN["raspberry-200"]
  },
  /**
   * Warning border color
   */
  "border-warning": {
    light: PALETTE_TOKEN["mango-600"],
    dark: PALETTE_TOKEN["mango-400"]
  },
  /**
   * Success border color
   */
  "border-success": {
    light: PALETTE_TOKEN["mint-600"],
    dark: PALETTE_TOKEN["mint-400"]
  },
  /**
   * Informative border color
   */
  "border-highlight": {
    light: PALETTE_TOKEN["skyblue-800"],
    dark: PALETTE_TOKEN["skyblue-600"]
  },
  /**
   * 요소 사이 구분 선
   */
  divide: {
    light: PALETTE_TOKEN["slate-100"],
    dark: PALETTE_TOKEN["slate-800"]
  },
  /**
   * 요소 사이의 보조 구분 선
   */
  "divide-sub": {
    light: PALETTE_TOKEN["slate-500"],
    dark: PALETTE_TOKEN["slate-800"]
  },
  /**
   * 요소 사이의 보조 구분 선
   */
  "divide-minimal": {
    light: PALETTE_TOKEN["slate-50"],
    dark: PALETTE_TOKEN["slate-800"]
  },
  /**
   * Default text, Primary label color
   */
  text: {
    light: PALETTE_TOKEN["slate-900"],
    dark: PALETTE_TOKEN["slate-white"]
  },
  /**
   * Sub text, Secondary label, Placeholder color
   */
  "text-sub": {
    light: PALETTE_TOKEN["slate-500"],
    dark: PALETTE_TOKEN["slate-500"]
  },
  /**
   * Disabled text, Placeholder disabled text color
   */
  "text-disabled": {
    light: PALETTE_TOKEN["slate-300"],
    dark: PALETTE_TOKEN["slate-600"]
  },
  /**
   * Error, Critical state text color
   */
  "text-critical": {
    light: PALETTE_TOKEN["raspberry-600"],
    dark: PALETTE_TOKEN["raspberry-400"]
  },
  /**
   * Error, Critical text hover color (액션 기능이 있을 경우)
   */
  "text-critical-hover": {
    light: PALETTE_TOKEN["raspberry-400"],
    dark: PALETTE_TOKEN["raspberry-200"]
  },
  /**
   * Warning state text color
   */
  "text-warning": {
    light: PALETTE_TOKEN["mango-700"],
    dark: PALETTE_TOKEN["mango-400"]
  },
  /**
   * Warning text hover color (액션 기능이 있을 경우)
   */
  "text-warning-hover": {
    light: PALETTE_TOKEN["mango-400"],
    dark: PALETTE_TOKEN["mango-200"]
  },
  /**
   * Success text color
   */
  "text-success": {
    light: PALETTE_TOKEN["mint-700"],
    dark: PALETTE_TOKEN["mint-400"]
  },
  /**
   * Link text, Primary text button color
   */
  "text-primary": {
    light: PALETTE_TOKEN["im-blue-500"],
    dark: PALETTE_TOKEN["im-blue-400"]
  },
  /**
   * Link text, Primary text button hover color
   */
  "text-primary-hover": {
    light: PALETTE_TOKEN["im-blue-300"],
    dark: PALETTE_TOKEN["im-blue-300"]
  },
  /**
   * Secondary text button color
   */
  "text-secondary": {
    light: PALETTE_TOKEN["slate-500"],
    dark: PALETTE_TOKEN["slate-300"]
  },
  /**
   * Secondary text button hover color
   */
  "text-secondary-hover": {
    light: PALETTE_TOKEN["slate-400"],
    dark: PALETTE_TOKEN["slate-200"]
  },
  /**
   * Primary, Critical, Text on button text color
   */
  "text-on": {
    light: PALETTE_TOKEN["slate-white"],
    dark: PALETTE_TOKEN["slate-white"]
  },
  /**
   * Default icon color
   */
  icon: {
    light: PALETTE_TOKEN["slate-900"],
    dark: PALETTE_TOKEN["slate-white"]
  },
  /**
   * Sub icon color
   */
  "icon-sub": {
    light: PALETTE_TOKEN["slate-500"],
    dark: PALETTE_TOKEN["slate-500"]
  },
  /**
   * Disabled icon color
   */
  "icon-disabled": {
    light: PALETTE_TOKEN["slate-300"],
    dark: PALETTE_TOKEN["slate-600"]
  },
  /**
   * Error, Critical state icon color
   */
  "icon-critical": {
    light: PALETTE_TOKEN["raspberry-600"],
    dark: PALETTE_TOKEN["raspberry-400"]
  },
  /**
   * Error, Critical icon hover color (액션 기능이 있을 경우)
   */
  "icon-critical-hover": {
    light: PALETTE_TOKEN["raspberry-400"],
    dark: PALETTE_TOKEN["raspberry-200"]
  },
  /**
   * Warning state icon color
   */
  "icon-warning": {
    light: PALETTE_TOKEN["mango-700"],
    dark: PALETTE_TOKEN["mango-400"]
  },
  /**
   * Warning icon hover color (액션 기능이 있을 경우)
   */
  "icon-warning-hover": {
    light: PALETTE_TOKEN["mango-400"],
    dark: PALETTE_TOKEN["mango-200"]
  },
  /**
   * Success icon color
   */
  "icon-success": {
    light: PALETTE_TOKEN["mint-700"],
    dark: PALETTE_TOKEN["mint-400"]
  },
  /**
   * Primary button icon color
   */
  "icon-primary": {
    light: PALETTE_TOKEN["im-blue-500"],
    dark: PALETTE_TOKEN["im-blue-400"]
  },
  /**
   * Primary button icon hover color
   */
  "icon-primary-hover": {
    light: PALETTE_TOKEN["im-blue-300"],
    dark: PALETTE_TOKEN["im-blue-300"]
  },
  /**
   * Secondary button icon color
   */
  "icon-secondary": {
    light: PALETTE_TOKEN["slate-500"],
    dark: PALETTE_TOKEN["slate-300"]
  },
  /**
   * Secondary button icon hover color
   */
  "icon-secondary-hover": {
    light: PALETTE_TOKEN["slate-400"],
    dark: PALETTE_TOKEN["slate-200"]
  },
  /**
   * Primary, Critical, Text on button text color
   */
  "icon-on": {
    light: PALETTE_TOKEN["slate-white"],
    dark: PALETTE_TOKEN["slate-white"]
  }
});

export { COLOR_TOKEN };
